package betterquesting.client.gui2.editors;

import betterquesting.api.client.gui.misc.INeedsRefresh;
import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasQuestDatabase;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetIcon;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.GuiQuest;
import betterquesting.network.handlers.NetQuestEdit;
import betterquesting.questing.QuestDatabase;
import java.util.Arrays;
import java.util.List;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import org.lwjgl.input.Keyboard;

/* loaded from: betterquesting_client_gui2_editors.jar:betterquesting/client/gui2/editors/GuiPrerequisiteEditor.class */
public class GuiPrerequisiteEditor extends GuiScreenCanvas implements IPEventListener, IVolatileScreen, INeedsRefresh {
    private IQuest quest;
    private final int questID;
    private CanvasQuestDatabase canvasDB;
    private CanvasScrolling canvasPreReq;

    public GuiPrerequisiteEditor(GuiScreen parent, IQuest quest) {
        super(parent);
        this.quest = quest;
        this.questID = QuestDatabase.INSTANCE.getID(quest);
    }

    public void refreshGui() {
        this.quest = (IQuest) QuestDatabase.INSTANCE.getValue(this.questID);
        if (this.quest == null) {
            this.field_146297_k.func_147108_a(this.parent);
        } else {
            this.canvasDB.refreshSearch();
            refreshReqCanvas();
        }
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        PanelTextBox panTxt = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.pre_requisites", new Object[0])).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        CanvasEmpty cvRight = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 32, 16, 24), 0));
        cvBackground.addPanel(cvRight);
        PanelTextBox txtDb = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate("betterquesting.gui.database", new Object[0])).setAlignment(1).setColor(PresetColor.TEXT_MAIN.getColor());
        cvRight.addPanel(txtDb);
        PanelTextField<String> searchBox = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 8, -32), 0), "", FieldFilterString.INSTANCE);
        searchBox.setWatermark("Search...");
        cvRight.addPanel(searchBox);
        this.canvasDB = new CanvasQuestDatabase(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 32, 8, 24), 0)) { // from class: betterquesting.client.gui2.editors.GuiPrerequisiteEditor.1
            /* JADX INFO: Access modifiers changed from: protected */
            public boolean addResult(DBEntry<IQuest> entry, int index, int width) {
                PanelButtonStorage<DBEntry<IQuest>> btnAdd = new PanelButtonStorage<>(new GuiRectangle(0, index * 16, 16, 16, 0), 2, "", entry);
                btnAdd.setIcon(PresetIcon.ICON_POSITIVE.getTexture());
                btnAdd.setActive(!GuiPrerequisiteEditor.this.containsReq(GuiPrerequisiteEditor.this.quest, entry.getID()));
                addPanel(btnAdd);
                PanelButtonStorage<DBEntry<IQuest>> btnEdit = new PanelButtonStorage<>(new GuiRectangle(16, index * 16, width - 32, 16, 0), 1, QuestTranslation.translate((String) ((IQuest) entry.getValue()).getProperty(NativeProps.NAME), new Object[0]), entry);
                addPanel(btnEdit);
                PanelButtonStorage<DBEntry<IQuest>> btnDel = new PanelButtonStorage<>(new GuiRectangle(width - 16, index * 16, 16, 16, 0), 4, "", entry);
                btnDel.setIcon(PresetIcon.ICON_TRASH.getTexture());
                addPanel(btnDel);
                return true;
            }
        };
        cvRight.addPanel(this.canvasDB);
        CanvasQuestDatabase canvasQuestDatabase = this.canvasDB;
        canvasQuestDatabase.getClass();
        searchBox.setCallback(canvasQuestDatabase::setSearchFilter);
        PanelVScrollBar scDb = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-8, 32, 0, 24), 0));
        cvRight.addPanel(scDb);
        this.canvasDB.setScrollDriverY(scDb);
        PanelButton btnNew = new PanelButton(new GuiTransform(GuiAlign.BOTTOM_EDGE, new GuiPadding(0, -16, 0, 0), 0), 5, QuestTranslation.translate("betterquesting.btn.new", new Object[0]));
        cvRight.addPanel(btnNew);
        CanvasEmpty cvLeft = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_LEFT, new GuiPadding(16, 32, 8, 24), 0));
        cvBackground.addPanel(cvLeft);
        PanelTextBox txtQuest = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate((String) this.quest.getProperty(NativeProps.NAME), new Object[0])).setAlignment(1).setColor(PresetColor.TEXT_MAIN.getColor());
        cvLeft.addPanel(txtQuest);
        this.canvasPreReq = new CanvasScrolling(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 16, 8, 0), 0));
        cvLeft.addPanel(this.canvasPreReq);
        PanelVScrollBar scReq = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-8, 16, 0, 0), 0));
        cvLeft.addPanel(scReq);
        this.canvasPreReq.setScrollDriverY(scReq);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -24, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
        refreshReqCanvas();
    }

    private void refreshReqCanvas() {
        this.canvasPreReq.resetCanvas();
        int width = this.canvasPreReq.getTransform().getWidth();
        List<DBEntry<IQuest>> arrReq = QuestDatabase.INSTANCE.bulkLookup(this.quest.getRequirements());
        for (int i = 0; i < arrReq.size(); i++) {
            PanelButtonStorage<DBEntry<IQuest>> btnEdit = new PanelButtonStorage<>(new GuiRectangle(0, i * 16, width - 16, 16, 0), 1, QuestTranslation.translate((String) ((IQuest) arrReq.get(i).getValue()).getProperty(NativeProps.NAME), new Object[0]), arrReq.get(i));
            this.canvasPreReq.addPanel(btnEdit);
            PanelButtonStorage<DBEntry<IQuest>> btnRem = new PanelButtonStorage<>(new GuiRectangle(width - 16, i * 16, 16, 16, 0), 3, "", arrReq.get(i));
            btnRem.setIcon(PresetIcon.ICON_NEGATIVE.getTexture());
            this.canvasPreReq.addPanel(btnRem);
        }
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() == 1 && (button instanceof PanelButtonStorage)) {
            this.field_146297_k.func_147108_a(new GuiQuest(this, ((DBEntry) button.getStoredValue()).getID()));
            return;
        }
        if (button.getButtonID() == 2 && (button instanceof PanelButtonStorage)) {
            addReq(this.quest, ((DBEntry) button.getStoredValue()).getID());
            SendChanges();
            return;
        }
        if (button.getButtonID() == 3 && (button instanceof PanelButtonStorage)) {
            removeReq(this.quest, ((DBEntry) button.getStoredValue()).getID());
            SendChanges();
            return;
        }
        if (button.getButtonID() == 4 && (button instanceof PanelButtonStorage)) {
            DBEntry<IQuest> entry = (DBEntry) button.getStoredValue();
            NBTTagCompound payload = new NBTTagCompound();
            payload.func_74783_a("questIDs", new int[]{entry.getID()});
            payload.func_74768_a("action", 1);
            NetQuestEdit.sendEdit(payload);
            return;
        }
        if (button.getButtonID() == 5) {
            NBTTagCompound payload2 = new NBTTagCompound();
            NBTTagList dataList = new NBTTagList();
            NBTTagCompound entry2 = new NBTTagCompound();
            entry2.func_74768_a("questID", -1);
            dataList.func_74742_a(entry2);
            payload2.func_74782_a("data", dataList);
            NetQuestEdit.sendEdit(payload2);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean containsReq(IQuest quest, int id) {
        for (int reqID : quest.getRequirements()) {
            if (id == reqID) {
                return true;
            }
        }
        return false;
    }

    private void removeReq(IQuest quest, int id) {
        int[] orig = quest.getRequirements();
        if (orig.length <= 0) {
            return;
        }
        boolean hasRemoved = false;
        int[] rem = new int[orig.length - 1];
        for (int i = 0; i < orig.length; i++) {
            if (!hasRemoved && orig[i] == id) {
                hasRemoved = true;
            } else if (!hasRemoved && i >= rem.length) {
                break;
            } else {
                rem[!hasRemoved ? i : i - 1] = orig[i];
            }
        }
        if (hasRemoved) {
            quest.setRequirements(rem);
        }
    }

    private void addReq(IQuest quest, int id) {
        if (containsReq(quest, id)) {
            return;
        }
        int[] orig = quest.getRequirements();
        int[] added = Arrays.copyOf(orig, orig.length + 1);
        added[orig.length] = id;
        quest.setRequirements(added);
    }

    private void SendChanges() {
        NBTTagCompound payload = new NBTTagCompound();
        NBTTagList dataList = new NBTTagList();
        NBTTagCompound entry = new NBTTagCompound();
        entry.func_74768_a("questID", this.questID);
        entry.func_74782_a("config", this.quest.writeToNBT(new NBTTagCompound()));
        dataList.func_74742_a(entry);
        payload.func_74782_a("data", dataList);
        payload.func_74768_a("action", 0);
        NetQuestEdit.sendEdit(payload);
    }
}
